"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
var path = require("path");
var index_1 = require("./index");
function cli(argv) {
    var directories = argv
        .filter(function (_, i) { return i > 1; });
    if (directories.length < 1) {
        console.log();
        console.log('Install packages locally without changing the package.json');
        console.log();
        console.log('Usage: install-local <folder>[, <folder>, ...]');
        console.log('');
        console.log('Installs a package from the filesystem into the current directory without touching the package.json.');
        console.log('');
        console.log('Examples: ');
        console.log(' install-local ..');
        console.log('   install the package located in the parent folder into the current directory.');
        console.log(' install-local ../sibling ../sibling2');
        console.log('   install the packages in 2 sibling directories into the current directory.');
        console.log(' install-local');
        console.log('   Print this help.');
        process.exit(1);
    }
    else {
        index_1.installLocal({ '.': directories }).then(function (packagesBySource) {
            Object.keys(packagesBySource).forEach(function (source) {
                console.log("Installed " + path.basename(source) + " into " + packagesBySource[source].map(function (target) { return path.basename(target); }));
            });
        }).catch(function (err) {
            console.error(err);
            process.exit(1);
        });
    }
}
exports.cli = cli;
//# sourceMappingURL=cli.js.map