"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
var childProcess = require("child_process");
var fs = require("fs");
var os = require("os");
var path = require("path");
function installLocal(packagesByTarget) {
    var packagesBySource = mapToPackagesBySource(packagesByTarget);
    return Promise.all(Object.keys(packagesBySource)
        .map(function (source) { return installPackagesInto(source, packagesBySource[source]); }))
        .then(function () { return packagesBySource; });
}
exports.installLocal = installLocal;
function mapToPackagesBySource(packagesByTarget) {
    var packagesBySource = {};
    Object.keys(packagesByTarget)
        .forEach(function (targetLocalPackage) { return packagesByTarget[targetLocalPackage].forEach(function (sourceLocalPackage) {
        var targetFullPath = path.resolve(targetLocalPackage);
        var sourceFullPath = path.resolve(sourceLocalPackage);
        var targetPackages = packagesBySource[sourceFullPath];
        if (!targetPackages) {
            targetPackages = [];
            packagesBySource[sourceFullPath] = targetPackages;
        }
        if (targetPackages.every(function (pkg) { return pkg !== targetFullPath; })) {
            targetPackages.push(targetFullPath);
        }
    }); });
    return packagesBySource;
}
exports.mapToPackagesBySource = mapToPackagesBySource;
function installPackagesInto(source, targets) {
    return Promise.all([
        readPackageJson(source).then(function (pck) { return path.resolve(pck.name + "-" + pck.version + ".tgz"); }),
        exec('', "npm pack " + source)
    ]).then(function (_a) {
        var packFile = _a[0];
        return Promise.all(targets.map(function (targetPackage) { return exec(targetPackage, "npm i --no-save " + packFile); }))
            .then(function () { return del(packFile); });
    });
}
function exec(cwd, command) {
    return new Promise(function (res, rej) {
        childProcess.exec(command, { cwd: cwd }, function (err, stdout, stderr) {
            if (err) {
                rej(err);
            }
            else {
                res("" + stdout + (stderr ? os.EOL + "stderr: " + stderr : ''));
            }
        });
    });
}
exports.exec = exec;
function readPackageJson(from) {
    return new Promise(function (res, rej) {
        fs.readFile(path.join(from, 'package.json'), 'utf8', function (err, content) {
            if (err) {
                rej(err);
            }
            else {
                res(JSON.parse(content));
            }
        });
    });
}
function del(file) {
    return new Promise(function (res, rej) { return fs.unlink(file, function (err) {
        if (err) {
            rej(err);
        }
        else {
            res(undefined);
        }
    }); });
}
//# sourceMappingURL=index.js.map